@@ -108,10 +108,11 @@ L_RR <- function(table, null=1, exp.RR=NULL, L.int=2, alpha=0.05, cc=FALSE, tole
   rr <- (a*(b+d))/(b*(a+c)) # RR from the contingency table
 
   res <- 100
-  arrlen <- res*c1tot-1
+  mintot <- min(r1tot,r2tot,c1tot,c2tot)
+  arrlen <- res*mintot-1
   xs <- 0; ys <- 0
 
-  for (i in 1:arrlen) {
+    for (i in 1:arrlen) {
     dv <- i/res
     ys[i] <- exp(-sum(a*log(a/dv), b*log(b/(c1tot-dv)), c*log(c/(r1tot-dv)), d*log(d/(r2tot-c1tot+dv))))
     xs[i] <- dv*r2tot/((c1tot-dv)*(r1tot))
@@ -123,14 +124,14 @@ L_RR <- function(table, null=1, exp.RR=NULL, L.int=2, alpha=0.05, cc=FALSE, tole
     (-sum(a*log(a/x), b*log(b/(c1tot-x)), c*log(c/(r1tot-x)), d*log(d/(r2tot-c1tot+x)))-goal)^2
   }
   xmin1 <- optimize(f, c(1, a), tol = toler, a, b, c, d, c1tot, r1tot, r2tot, goal)
-  xmin2 <- optimize(f, c(a, c1tot), tol = toler, a, b, c, d, c1tot, r1tot, r2tot, goal)
+  xmin2 <- optimize(f, c(a, mintot), tol = toler, a, b, c, d, c1tot, r1tot, r2tot, goal)
   beg <- xmin1$minimum*r2tot/((c1tot-xmin1$minimum)*r1tot)
   end <- xmin2$minimum*r2tot/((c1tot-xmin2$minimum)*r1tot)
 
   # same for likelihood
   goalL <- -L.int
   xmin1L <- optimize(f, c(1, a), tol = toler, a, b, c, d, c1tot, r1tot, r2tot, goalL)
-  xmin2L <- optimize(f, c(a, c1tot), tol = toler, a, b, c, d, c1tot, r1tot, r2tot, goalL)
+  xmin2L <- optimize(f, c(a, mintot), tol = toler, a, b, c, d, c1tot, r1tot, r2tot, goalL)
   begL <- xmin1L$minimum*r2tot/((c1tot-xmin1L$minimum)*r1tot)
   endL <- xmin2L$minimum*r2tot/((c1tot-xmin2L$minimum)*r1tot)
 
@@ -157,7 +158,7 @@ L_RR <- function(table, null=1, exp.RR=NULL, L.int=2, alpha=0.05, cc=FALSE, tole
   h <- function(x,c1tot,r1tot,r2tot,goal) {
     (x*(r2tot)/((c1tot-x)*(r1tot))-goal)^2
   }
-  exan <- optimize(h, c(1, c1tot), tol = toler, c1tot, r1tot, r2tot, goal)
+  exan <- optimize(h, c(1, mintot), tol = toler, c1tot, r1tot, r2tot, goal)
   xa <- unname(unlist(exan[1]))
   nullh <- exp(-sum(a*log(a/xa), b*log(b/(c1tot-xa)), c*log(c/(r1tot-xa)), d*log(d/(r2tot-c1tot+xa))))
 
